flame_noise
library
Functions
-
buildNoise({int seed = 1337, double frequency = .01, Interp interp = Interp.quintic, NoiseType noiseType = NoiseType.simplex, int octaves = 3, double lacunarity = 2.0, double gain = .5, FractalType fractalType = FractalType.fbm, CellularDistanceFunction cellularDistanceFunction = CellularDistanceFunction.euclidean, CellularReturnType cellularReturnType = CellularReturnType.cellValue})
→ Noise2And3
-
-
calculateFractalBounding(int octaves, double gain)
→ double
-
-
gradCoord2D(int seed, int x, int y, double xd, double yd)
→ double
-
-
gradCoord3D(int seed, int x, int y, int z, double xd, double yd, double zd)
→ double
-
-
gradCoord4D(int seed, int x, int y, int z, int w, double xd, double yd, double zd, double wd)
→ double
-
-
hash2D(int seed, int x, int y)
→ int
-
-
hash3D(int seed, int x, int y, int z)
→ int
-
-
noise2(int width, int height, {int seed = 1337, double frequency = .01, Interp interp = Interp.quintic, NoiseType noiseType = NoiseType.simplex, int octaves = 3, double lacunarity = 2.0, double gain = .5, FractalType fractalType = FractalType.fbm, CellularDistanceFunction cellularDistanceFunction = CellularDistanceFunction.euclidean, CellularReturnType cellularReturnType = CellularReturnType.cellValue})
→ List<List<double>>
-
Creates 2D noise
-
noise3(int width, int height, int depth, {int seed = 1337, double frequency = .01, Interp interp = Interp.quintic, NoiseType noiseType = NoiseType.simplex, int octaves = 3, double lacunarity = 2.0, double gain = .5, FractalType fractalType = FractalType.fbm, CellularDistanceFunction cellularDistanceFunction = CellularDistanceFunction.euclidean, CellularReturnType cellularReturnType = CellularReturnType.cellValue})
→ List<List<List<double>>>
-
Creates 3D noise
-
valCoord2D(int seed, int x, int y)
→ double
-
-
valCoord3D(int seed, int x, int y, int z)
→ double
-
-
valCoord4D(int seed, int x, int y, int z, int w)
→ double
-